@@ -37,7 +37,6 @@ def null():
         if data is not None:
             yield
             pass
-            #print data
 
 
 def read_from_file(filename):
@@ -390,7 +389,9 @@ def combine_selectors(lines):
     first = True
     stack = []
     selectors = [[]]
-    for f, n, name, level, behind, sel, _sel in lines:
+    _level, _sel = -1, True
+    for f, n, name, level, _, sel, _ in lines:
+        behind = level - _level
         if sel and (_sel and behind > 0 or not _sel and behind == 0):
             stack.append(selectors)
             selectors = [s + [name] for s in selectors]
@@ -407,6 +408,7 @@ def combine_selectors(lines):
                     sel_ = True
                 first = False
             yield name, sel, _sel
+        _level, _sel = level, sel
 
 
 def make_statements_list(lines):
@@ -597,7 +599,7 @@ def process_pass(filename, compressed=True, empty_selectors=True, respect_indent
     importer = import_pass_file(reader)
     # f, n, line
     lines = first_line_update_by_parent(importer, target, compressed, empty_selectors, respect_indents,
-                 inherit_selectors, indent, css_indent, newlines)
+                                        inherit_selectors, indent, css_indent, newlines)
     lines = ignore_empty_lines(lines, target)
     lines = ignore_line_comments(lines, target)
     lines = ignore_block_comments(lines, target)
@@ -610,9 +612,9 @@ def process_pass(filename, compressed=True, empty_selectors=True, respect_indent
     lines = check_media_queries_syntax(lines)
     #lines = filter_properties(lines)
     lines = evaluate_properties(lines)
-
-    # с этого момента структура файла изменилась
-
+    ######################
+    # Structural changes #
+    ######################
     lines = combine_selectors(lines)
     # name, sel, _sel
     lines = make_statements_list(lines)
